aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/query2
diff options
context:
space:
mode:
authorGravatar jcater <jcater@google.com>2018-06-21 12:19:48 -0700
committerGravatar Copybara-Service <copybara-piper@google.com>2018-06-21 12:21:00 -0700
commit1a025f53f85c70323a3657b692ed9394f6efe721 (patch)
tree7d0e99d446a78f5b58f3f3ef2b9e7df805f7de10 /src/main/java/com/google/devtools/build/lib/query2
parent474d4a1bd59a1c41d6c23b1ee7fce08df903afc7 (diff)
Rename the implicit attribute used to store toolchain dependencies.
PiperOrigin-RevId: 201565941
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/query2')
-rw-r--r--src/main/java/com/google/devtools/build/lib/query2/TransitionsOutputFormatterCallback.java11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/query2/TransitionsOutputFormatterCallback.java b/src/main/java/com/google/devtools/build/lib/query2/TransitionsOutputFormatterCallback.java
index a84386b36a..27685267e8 100644
--- a/src/main/java/com/google/devtools/build/lib/query2/TransitionsOutputFormatterCallback.java
+++ b/src/main/java/com/google/devtools/build/lib/query2/TransitionsOutputFormatterCallback.java
@@ -127,10 +127,11 @@ public class TransitionsOutputFormatterCallback extends CqueryThreadsafeCallback
((RuleConfiguredTarget) configuredTarget).getConfigConditions();
BuildOptions fromOptions = config.getOptions();
try {
// Note: Being able to pull the $toolchain attr unconditionally from the mapper relies on
// the fact that {@link PlatformSemantics.TOOLCHAIN_ATTRS} exists in every rule.
// Also, we don't actually use fromOptions in our implementation of DependencyResolver but
// passing to avoid passing a null and since we have the information anyway.
deps =
new FormatterDependencyResolver(configuredTarget, reporter)
.dependentNodeMap(
@@ -140,7 +141,7 @@ public class TransitionsOutputFormatterCallback extends CqueryThreadsafeCallback
configConditions,
ImmutableSet.copyOf(
ConfiguredAttributeMapper.of(target.getAssociatedRule(), configConditions)
- .get(PlatformSemantics.TOOLCHAINS_ATTR, BuildType.LABEL_LIST)),
+ .get(PlatformSemantics.RESOLVED_TOOLCHAINS_ATTR, BuildType.LABEL_LIST)),
fromOptions,
trimmingTransitionFactory);
} catch (EvalException | InvalidConfigurationException | InconsistentAspectOrderException e) {
@@ -127,10 +127,11 @@ public class TransitionsOutputFormatterCallback extends CqueryThreadsafeCallback
BuildOptions fromOptions = config.getOptions();
try {
- // Note: Being able to pull the $toolchain attr unconditionally from the mapper relies on
- // the fact that {@link PlatformSemantics.TOOLCHAIN_ATTRS} exists in every rule.
- // Also, we don't actually use fromOptions in our implementation of DependencyResolver but
- // passing to avoid passing a null and since we have the information anyway.
+ // Note: Being able to pull the $resolved_toolchain_internal attr unconditionally from the
+ // mapper relies on the fact that {@link PlatformSemantics.RESOLVED_TOOLCHAINS_ATTR} exists
+ // in every rule. Also, we don't actually use fromOptions in our implementation of
+ // DependencyResolver but passing to avoid passing a null and since we have the information
+ // anyway.
deps =
new FormatterDependencyResolver(configuredTarget, reporter)